==> oh-my-posh-21.18.2.tar.gz: oh-my-posh-21.18.2/src/upgrade/install.go <==
package upgrade

import (
	"bytes"
	"context"
	"fmt"
	"io"
	httplib "net/http"
	"os"
	"path/filepath"
	stdruntime "runtime"

	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
)

func install() error {
	setState(validating)

	executable, err := os.Executable()
	if err != nil {
		return err
	}

	extension := ""
	if stdruntime.GOOS == runtime.WINDOWS {
		extension = ".exe"
	}

	asset := fmt.Sprintf("posh-%s-%s%s", stdruntime.GOOS, stdruntime.GOARCH, extension)

	setState(downloading)

	url := fmt.Sprintf("https://github.com/JanDeDobbeleer/oh-my-posh/releases/latest/download/%s", asset)

	req, err := httplib.NewRequestWithContext(context.Background(), "GET", url, nil)
	if err != nil {
		return err
	}

	resp, err := http.HTTPClient.Do(req)
	if err != nil {
		return err
	}

	if resp.StatusCode != httplib.StatusOK {
		return fmt.Errorf("failed to download installer: %s", url)
	}

	defer resp.Body.Close()

	newBytes, err := io.ReadAll(resp.Body)
	if err != nil {
		return err
	}

	targetDir := filepath.Dir(executable)
	fileName := filepath.Base(executable)

	newPath := filepath.Join(targetDir, fmt.Sprintf(".%s.new", fileName))
	fp, err := os.OpenFile(newPath, os.O_CREATE|os.O_WRONLY|os.O_TRUNC, 0775)
	if err != nil {
		return err
	}

	defer fp.Close()

	_, err = io.Copy(fp, bytes.NewReader(newBytes))
	if err != nil {
		return err
	}

	// windows will have a lock when we do not close the file
	fp.Close()

	oldPath := filepath.Join(targetDir, fmt.Sprintf(".%s.old", fileName))

	_ = os.Remove(oldPath)

	err = os.Rename(executable, oldPath)
	if err != nil {
		return err
	}

	err = os.Rename(newPath, executable)

	if err != nil {
		// rollback
		rerr := os.Rename(oldPath, executable)
		if rerr != nil {
			return rerr
		}

		return err
	}

	removeErr := os.Remove(oldPath)

	// hide the old executable if we can't remove it
	if removeErr != nil {
		_ = hideFile(oldPath)
	}

	return nil
}

==> oh-my-posh-26.8.0.tar.gz: oh-my-posh-26.8.0/src/upgrade/install.go <==
package upgrade

import (
	"bytes"
	"errors"
	"fmt"
	"io"
	"os"
	"path/filepath"

	"github.com/jandedobbeleer/oh-my-posh/src/log"
)

func install(cfg *Config) error {
	setState(validating)

	executable, err := os.Executable()
	if err != nil {
		log.Debug("failed to get executable path")
		return err
	}

	targetDir := filepath.Dir(executable)
	fileName := filepath.Base(executable)

	newPath := filepath.Join(targetDir, fmt.Sprintf(".%s.new", fileName))
	fp, err := os.OpenFile(newPath, os.O_CREATE|os.O_WRONLY|os.O_TRUNC, 0775)
	if err != nil {
		log.Error(err)
		return errors.New("we do not have permissions to update")
	}

	setState(downloading)

	data, err := downloadAndVerify(cfg)
	if err != nil {
		log.Debug("failed to download and verify")
		return err
	}

	setState(installing)

	_, err = io.Copy(fp, bytes.NewReader(data))
	// windows will have a lock when we do not close the file
	fp.Close()

	if err != nil {
		log.Debug("failed to copy data to new file")
		return err
	}

	oldPath := filepath.Join(targetDir, fmt.Sprintf(".%s.old", fileName))

	_ = os.Remove(oldPath)

	err = os.Rename(executable, oldPath)
	if err != nil {
		log.Debug("failed to rename old file")
		return err
	}

	err = os.Rename(newPath, executable)

	if err != nil {
		log.Debug("failed to rename new file, rolling back")
		// rollback
		rerr := os.Rename(oldPath, executable)
		if rerr != nil {
			log.Debug("failed to rollback old file")
			return rerr
		}

		return err
	}

	removeErr := os.Remove(oldPath)

	// hide the old executable if we can't remove it
	if removeErr != nil {
		log.Error(removeErr)
		// hide the old executable
		_ = hideFile(oldPath)
	}

	return nil
}
